@@ -2,6 +2,7 @@ import express from 'express';
 
 import { constructPermission } from '@tamanu/shared/permissions/middleware';
 import { settingsCache } from '@tamanu/settings';
+import { attachAuditUserToDbSession } from '@tamanu/database/utils/audit';
 
 import {
   authMiddleware,
@@ -77,15 +78,12 @@ apiv1.get(
   }),
 );
 
-apiv1.get(
-  '/public/translation/languageOptions',
-  asyncHandler(async (req, res) => {
-    req.flagPermissionChecked();
-    const { TranslatedString } = req.models;
-    const response = await TranslatedString.getPossibleLanguages();
-    res.send(response);
-  }),
-);
+apiv1.get('/public/translation/languageOptions', async (req, res) => {
+  req.flagPermissionChecked();
+  const { TranslatedString } = req.models;
+  const response = await TranslatedString.getPossibleLanguages();
+  res.send(response);
+});
 
 apiv1.get(
   '/public/translation/:language',
@@ -111,6 +109,8 @@ apiv1.use(authMiddleware);
 
 apiv1.use(constructPermission);
 
+apiv1.use(attachAuditUserToDbSession);
+
 apiv1.delete(
   '/admin/settings/cache',
   asyncHandler(async (req, res) => {
